Greenland: Pythonic Infrastructure
==================================

(more docu in preparation)

Source code is available from the `git repository`_. See
`CHANGELOG.rst`_ for changes and release history.

.. _CHANGELOG.rst:  file:CHANGELOG.rst
.. _git repository: https://github.com/m-e-leypold/greenland4


LICENSE
-------

Greenland is free Software and licensed by the terms of the Gnu Public
License, version 3 or later (GPL3).

For details and the full license text see the file LICENSE.txt at the
top of the source tree.


